@@ -1,12 +1,14 @@
 from typing import Sequence, List, Set, Tuple
+import random
 from abc import abstractmethod, ABC
 from ase import Atoms
-import numpy as np
-from clease.montecarlo.constraints import MCConstraint
 from clease.datastructures import SystemChange
-from clease.montecarlo.swap_move_index_tracker import SwapMoveIndexTracker
+from clease.tools import flatten
+from .constraints import MCConstraint
+from .swap_move_index_tracker import SwapMoveIndexTracker
 
-__all__ = ('TrialMoveGenerator', 'RandomFlip', 'RandomSwap', 'MixedSwapFlip', 'TooFewElementsError')
+__all__ = ('TrialMoveGenerator', 'RandomFlip', 'RandomSwap', 'MixedSwapFlip', 'TooFewElementsError',
+           'RandomFlipWithinBasis')
 
 DEFAULT_MAX_ATTEMPTS = 10000
 
@@ -146,9 +148,9 @@ class RandomFlip(SingleTrialMoveGenerator):
             self.indices = indices
 
     def get_single_trial_move(self) -> List[SystemChange]:
-        pos = np.random.choice(self.indices)
+        pos = random.choice(self.indices)
         old_symb = self.atoms[pos].symbol
-        new_symb = np.random.choice([s for s in self.symbols if s != old_symb])
+        new_symb = random.choice([s for s in self.symbols if s != old_symb])
         return [
             SystemChange(index=pos, old_symb=old_symb, new_symb=new_symb, name=self.CHANGE_NAME)
         ]
@@ -186,8 +188,8 @@ class RandomSwap(SingleTrialMoveGenerator):
         """
         Create a swap move
         """
-        symb_a = np.random.choice(self.tracker.symbols)
-        symb_b = np.random.choice([s for s in self.tracker.symbols if s != symb_a])
+        symb_a = random.choice(self.tracker.symbols)
+        symb_b = random.choice([s for s in self.tracker.symbols if s != symb_a])
         rand_pos_a = self.tracker.get_random_indx_of_symbol(symb_a)
         rand_pos_b = self.tracker.get_random_indx_of_symbol(symb_b)
         return [
@@ -236,6 +238,11 @@ class MixedSwapFlip(TrialMoveGenerator):
     def generators(self) -> Tuple[SingleTrialMoveGenerator]:
         return (self.flipper, self.swapper)
 
+    @property
+    def weights(self) -> Tuple[float]:
+        """The probability weights for each generator"""
+        return (self.flip_prob, 1.0 - self.flip_prob)
+
     def initialize(self, atoms: Atoms) -> None:
         """
         Initialize the trial move generator
@@ -248,7 +255,7 @@ class MixedSwapFlip(TrialMoveGenerator):
         Produce a single trial move. Return a swap move with
         probability
         """
-        gen = np.random.choice(self.generators, p=[self.flip_prob, 1.0 - self.flip_prob])
+        gen = random.choices(self.generators, weights=self.weights, k=1)[0]
         return gen.get_single_trial_move()
 
     def on_move_accepted(self, changes: Sequence[SystemChange]):
@@ -268,3 +275,70 @@ class MixedSwapFlip(TrialMoveGenerator):
             gen_changes = gen.made_changes(changes)
             if gen_changes:
                 gen.on_move_rejected(gen_changes)
+
+
+class RandomFlipWithinBasis(SingleTrialMoveGenerator):
+    """
+    Produce trial moves consisting of flips within each basis. Each basis
+    is defined by a list of indices.
+
+    Args:
+        symbols: Sequence allowed symbols in each basis
+        atoms: Atoms object to be used in the simulation for which the trial
+            moves are produced
+        indices: Sequence of sets of indices where each set specify the indices
+            of a basis. Note len(symbols) == len(indices)
+
+    Example:
+
+    Create a generator for a rocksalt structure with two basis
+
+    >>> from ase.build import bulk
+    >>> from clease.montecarlo import RandomFlipWithinBasis
+    >>> atoms = bulk("LiO", crystalstructure="rocksalt", a=3.9)*(3, 3, 3)
+    >>> basis1 = [a.index for a in atoms if a.symbol == "Li"]
+    >>> basis2 = [a.index for a in atoms if a.symbol == "O"]
+    >>> generator = RandomFlipWithinBasis([["Li", "X"], ["O", "V"]], atoms, [basis1, basis2])
+    """
+
+    CHANGE_NAME = 'flip_within_basis_move'
+
+    def __init__(self,
+                 symbols: Sequence[Sequence[str]],
+                 atoms: Atoms,
+                 indices: Sequence[Sequence[int]] = None,
+                 **kwargs):
+        super().__init__(**kwargs)
+
+        if len(symbols) != len(indices):
+            raise ValueError("Possible symbols must be specified for all basis.")
+
+        if not _symbols_in_basis_are_unique(symbols):
+            raise ValueError("Symbols within each basis must be unique")
+
+        if not _index_occur_only_once(indices):
+            raise ValueError("Each index can only occur in one basis and only once in each basis.")
+
+        self._flippers = [RandomFlip(s, atoms, i) for s, i in zip(symbols, indices)]
+
+    def get_single_trial_move(self) -> Sequence[SystemChange]:
+        """
+        Produce a trial move by choosing a random flipper
+        """
+        flipper = random.choice(self._flippers)
+        return flipper.get_single_trial_move()
+
+
+def _symbols_in_basis_are_unique(nested_seq: Sequence[Sequence[str]]) -> bool:
+    """
+    Check if all items in the sub-lists are unique.
+    """
+    for sub in nested_seq:
+        if len(sub) != len(set(sub)):
+            return False
+    return True
+
+
+def _index_occur_only_once(nested_seq: Sequence[Sequence[int]]) -> bool:
+    flattened = flatten(nested_seq)
+    return len(flattened) == len(set(flattened))
